Struct ZwlrOutputPowerV1
pub struct ZwlrOutputPowerV1 { /* private fields */ }wayland and Linux only.Expand description
adjust power management mode for an output
This object offers requests to set the power management mode of an output.
See also the Request enum for this interface.
Implementations
impl ZwlrOutputPowerV1
impl ZwlrOutputPowerV1
pub fn mode(&self, mode: Mode)
pub fn mode(&self, mode: Mode)
Report a power management mode change
Report the power management mode change of an output.
The mode event is sent after an output changed its power management mode. The reason can be a client using set_mode or the compositor deciding to change an output’s mode. This event is also sent immediately when the object is created so the client is informed about the current power management mode.
pub fn failed(&self)
pub fn failed(&self)
object no longer valid
This event indicates that the output power management mode control is no longer valid. This can happen for a number of reasons, including:
- The output doesn’t support power management
- Another client already has exclusive power management mode control for this output
- The output disappeared
Upon receiving this event, the client should destroy this object.